@@ -140,7 +140,7 @@ class RoborockSocketListener(asyncio.Protocol):
             if not self.is_connected():
                 async with async_timeout.timeout(self.timeout):
                     _LOGGER.info(f"Connecting to {self.ip}")
-                    self.transport, _ = await self.loop.create_connection(lambda: self, self.ip, 58867)
+                    self.transport, _ = await self.loop.create_connection(lambda: self, self.ip, 58867)  # type: ignore
         except Exception as e:
             raise RoborockConnectionException(f"Failed connecting to {self.ip}") from e
 
