@@ -168,7 +168,7 @@ CommandInfoMap: dict[RoborockCommand, CommandInfo] = {
     RoborockCommand.FIND_ME: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.RESUME_ZONED_CLEAN: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.RESUME_SEGMENT_CLEAN: CommandInfo(prefix=b"\x00\x00\x00\x87"),
-    RoborockCommand.RESET_CONSUMABLE: CommandInfo(prefix=b"\x00\x00\x00w"),
+    RoborockCommand.RESET_CONSUMABLE: CommandInfo(prefix=b"\x00\x00\x00\x97"),
     RoborockCommand.LOAD_MULTI_MAP: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.APP_RC_START: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.APP_RC_END: CommandInfo(prefix=b"\x00\x00\x00w"),
